<div class="dashboard-header">
    <nav class="navbar navbar-expand-lg bg-white fixed-top">
        <a class="navbar-brand" href="/">RQ Monitor</a>
        <select class="mr-5" id="redis_instances" name="redis" style="width: 55%">
            {% for redis_instance in redis_instance_list %}
            <option value="{{redis_instance}}">{{redis_instance}}</option>
            {% endfor %}
        </select>
        {% include 'rqmonitor/redis_memory.html' %}
    </nav>
</div>