<div class="navbar-redis-memory border border-primary p-1 ml-5">
    <span class="ml-1">RQ Redis Memory</span>
        <span class="ml-1 mt-2">
            <img class="mb-1" height="32px" width="32px" src="{{ url_for('static', filename='assets/images/redis.png') }}"></img>
        </span>
    </span>
    <span id="redis_memory_value" class="ml-1">{{ redis_memory_used }}</span>
    <a href="#" id="redis_memory_refresh" class="ml-2 mr-1">
        <i class="fas fa-sync"></i>
    </a>
</div>
