<div id="main_content" class="container-fluid dashboard-content">
    <div class="row">
      <div class="col-xl-12 col-lg-12 col-md-12 col-sm-12 col-12">
        {% block actionbuttons %}
          <button type="button" data-action="deleteall" data-toggle="modal" data-target="#confirmation"  
          class="btn btn-danger float-right" data-targetclass="queue">Delete Selected Queues</button>
          <button type="button" data-action="emptyall" data-toggle="modal" data-target="#confirmation"  
          class="btn btn-warning float-right mr-2" data-targetclass="queue">Empty Selected Queues</button>
        {% endblock %}
      </div>
    </div>
    <div class="row">
      <div class="col-xl-12 col-lg-12 col-md-12 col-sm-12 col-12">
        <div class="card">
          <div class="card-body">
            <div class="table-responsive">
                {% block table %}
                    {% include 'rqmonitor/table_queues.html' %}
                {% endblock %}
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>