<div id="infomodal" class="modal fade" tabindex="-1" role="dialog" aria-labelledby="myLargeModalLabel"
  aria-hidden="true">
  <div class="modal-dialog modal-lg">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title" id="exampleModalLongTitle">Worker Name</h5>
        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
      <div class="modal-body">
        <table class="table table-bordered">
          <thead>
            <tr>
              <th scope="col">Attribute</th>
              <th scope="col">Value</th>
            </tr>
          </thead>
          <tbody>
            <tr>
              <th scope="row">Birth Date</th>
              <td id="birth_date"></td>
            </tr>
            <tr>
              <th scope="row">Death Date</th>
              <td id="death_date"></td>
            </tr>
            <tr>
              <th scope="row">Failed Job Count</th>
              <td id="failed_job_count"></td>
            </tr>
            <tr>
              <th scope="row">Successful Job Count</th>
              <td id="successful_job_count"></td>
            </tr>
            <tr>
              <th scope="row">Job Monitoring Interval</th>
              <td id="job_monitoring_interval"></td>
            </tr>
            <tr>
              <th scope="row">Last Heartbeat</th>
              <td id="last_heartbeat"></td>
            </tr>
            <tr>
              <th scope="row">Current Job ID</th>
              <td id="current_job_id"></td>
            </tr>
            <tr>
              <th scope="row">Last Cleaned At</th>
              <td id="last_cleaned_at"></td>
            </tr>
            <tr>
              <th scope="row">Host Name</th>
              <td id="host_name"></td>
            </tr>
            <tr>
              <th scope="row">Worker TTL</th>
              <td id="worker_ttl"></td>
            </tr>
            <tr>
              <th scope="row">Result TTL</th>
              <td id="result_ttl"></td>
            </tr>
          </tbody>
        </table>
      </div>
    </div>
  </div>
</div>