<!-- Confirmation Worker Delete Modal -->
<div class="modal fade" id="confirmation" tabindex="-1" role="dialog" aria-labelledby="exampleModalCenterTitle"
aria-hidden="true">
<div class="modal-dialog modal-dialog-centered" role="document">
  <div class="modal-content">
    <div class="modal-header">
      <h5 class="modal-title" style="word-wrap: break-word;">Modal Title</h5>
      <button type="button" class="close" data-dismiss="modal" aria-label="Close">
        <span aria-hidden="true">&times;</span>
      </button>
    </div>
    <div class="modal-body" style="word-wrap: break-word;">
      Modal Body
    </div>
    <div class="modal-footer">
      <button type="button" id="modalcancel" class="btn btn-secondary" data-dismiss="modal">Cancel</button>
      <button type="button" id="modalsubmit" class="btn btn-primary confirm">Confirm</button>
    </div>
  </div>
</div>
</div>