<table class="table table-bordered table-hover" id="workers_table">
  <thead>
  <tr>
    <th>Worker Name</th>
    <th>Listening On</th>
    <th>Status</th>
    <th>Host IP</th>
    <th>Current Job ID</th>
    <th>Failed Jobs</th>
    <th>Action</th>
  </tr>
  </thead>
</table>