{% extends "rqmonitor/base_dashboard.html" %}
{% block actionbuttons %}
  <button type="button" data-action="requeueall" data-toggle="modal" data-target="#confirmation"  
  class="btn btn-primary float-right" data-targetclass="job" >Requeue Failed Jobs</button>
  <button type="button" data-action="cancelall" data-toggle="modal" data-target="#confirmation"  
  class="btn btn-warning float-right mr-2" data-targetclass="job">Cancel Queued Jobs</button>
  <button type="button" data-action="deleteall" data-toggle="modal" data-target="#confirmation" 
  class="btn btn-danger float-right mr-2" data-targetclass="job">Delete All Jobs</button>
{% endblock %}
{% block table %}
  {% include 'rqmonitor/table_jobs.html' %}
{% endblock %}